@@ -15,13 +15,14 @@ from astropy.extern import six
 from astropy.table import Table, Column
 from astropy import log
 
-from ..exceptions import LoginError, RemoteServiceError
+from ..exceptions import LoginError, RemoteServiceError, NoResultsWarning
 from ..utils import schema, system_tools
 from ..query import QueryWithLogin, suspend_cache
 from . import conf
 
 __doctest_skip__ = ['EsoClass.*']
 
+
 def _check_response(content):
     """
     Check the response from an ESO service query for various types of error
@@ -75,8 +76,10 @@ class EsoClass(QueryWithLogin):
                     fmt = 'multipart/form-data'  # post(url, files=payload)
                 elif form.attrs['enctype'] == 'application/x-www-form-urlencoded':
                     fmt = 'application/x-www-form-urlencoded'  # post(url, data=payload)
+                else:
+                    raise Exception("enctype={0} is not supported!".format(form.attrs['enctype']))
             else:
-                fmt = 'post'  # post(url, params=payload)
+                fmt = 'application/x-www-form-urlencoded'  # post(url, data=payload)
         # Extract payload from form
         payload = []
         for form_elem in form.find_all(['input', 'select', 'textarea']):
@@ -87,7 +90,7 @@ class EsoClass(QueryWithLogin):
             if tag_name == 'input':
                 is_file = (form_elem.get('type') == 'file')
                 value = form_elem.get('value')
-                if form_elem.get('type') == 'checkbox':
+                if form_elem.get('type') in ['checkbox', 'radio']:
                     if form_elem.has_attr('checked'):
                         if not value:
                             value = 'on'
@@ -96,20 +99,39 @@ class EsoClass(QueryWithLogin):
             elif tag_name == 'select':
                 if form_elem.get('multiple') is not None:
                     value = []
-                    for option in form_elem.select('option[value]'):
-                        if option.get('selected') is not None:
-                            value.append(option.get('value'))
+                    if form_elem.select('option[value]'):
+                        for option in form_elem.select('option[value]'):
+                            if option.get('selected') is not None:
+                                value.append(option.get('value'))
+                    else:
+                        for option in form_elem.select('option'):
+                            if option.get('selected') is not None:
+                                value.append(option.string)
                 else:
-                    for option in form_elem.select('option[value]'):
-                        if option.get('selected') is not None:
-                            value = option.get('value')
-                    # select the first option field if none is selected
-                    if value is None:
-                        value = form_elem.select('option[value]')[0].get('value')
+                    if form_elem.select('option[value]'):
+                        for option in form_elem.select('option[value]'):
+                            if option.get('selected') is not None:
+                                value = option.get('value')
+                        # select the first option field if none is selected
+                        if value is None:
+                            value = form_elem.select(
+                                'option[value]')[0].get('value')
+                    else:
+                        # survey form just uses text, not value
+                        for option in form_elem.select('option'):
+                            if option.get('selected') is not None:
+                                value = option.string
+                        # select the first option field if none is selected
+                        if value is None:
+                            value = form_elem.select('option')[0].string
 
             if key in inputs:
-                value = str(inputs[key])
-            if (key is not None) and (value is not None):
+                if isinstance(inputs[key], list):
+                    # list input is accepted (for array uploads)
+                    value = inputs[key]
+                else:
+                    value = str(inputs[key])
+            if (key is not None):# and (value is not None):
                 if fmt == 'multipart/form-data':
                     if is_file:
                         payload.append(
@@ -118,6 +140,8 @@ class EsoClass(QueryWithLogin):
                         if type(value) is list:
                             for v in value:
                                 payload.append((key, ('', v)))
+                        elif value is None:
+                            payload.append((key, ('', '')))
                         else:
                             payload.append((key, ('', value)))
                 else:
@@ -134,11 +158,11 @@ class EsoClass(QueryWithLogin):
         if method is not None:
             fmt = method
 
+        log.debug("Method/format = {0}".format(fmt))
+
         # Send payload
         if fmt == 'get':
             response = self._request("GET", url, params=payload, cache=cache)
-        elif fmt == 'post':
-            response = self._request("POST", url, params=payload, cache=cache)
         elif fmt == 'multipart/form-data':
             response = self._request("POST", url, files=payload, cache=cache)
         elif fmt == 'application/x-www-form-urlencoded':
@@ -146,29 +170,53 @@ class EsoClass(QueryWithLogin):
 
         return response
 
-    def _login(self, username=None, store_password=False):
+    def _login(self, username=None, store_password=False,
+               reenter_password=False):
+        """
+        Login to the ESO User Portal.
+
+        Parameters
+        ----------
+        username : str, optional
+            Username to the ESO Public Portal. If not given, it should be
+            specified in the config file.
+        store_password : bool, optional
+            Stores the password securely in your keyring. Default is False.
+        reenter_password : bool, optional
+            Asks for the password even if it is already stored in the
+            keyring. This is the way to overwrite an already stored passwork
+            on the keyring. Default is False.
+        """
         if username is None:
             if self.USERNAME == "":
-                raise LoginError("If you do not pass a username to login(), you should configure a default one!")
+                raise LoginError("If you do not pass a username to login(), "
+                                 "you should configure a default one!")
             else:
                 username = self.USERNAME
+
         # Get password from keyring or prompt
-        password_from_keyring = keyring.get_password("astroquery:www.eso.org", username)
+        if reenter_password is False:
+            password_from_keyring = keyring.get_password(
+                "astroquery:www.eso.org", username)
+        else:
+            password_from_keyring = None
+
         if password_from_keyring is None:
             if system_tools.in_ipynb():
                 log.warn("You may be using an ipython notebook:"
                          " the password form will appear in your terminal.")
-            password = getpass.getpass("{0}, enter your ESO password:\n".format(username))
+            password = getpass.getpass("{0}, enter your ESO password:\n"
+                                       .format(username))
         else:
             password = password_from_keyring
         # Authenticate
         log.info("Authenticating {0} on www.eso.org...".format(username))
         # Do not cache pieces of the login process
-        login_response = self._request("GET", "https://www.eso.org/sso/login", cache=False)
-        login_result_response = self._activate_form(login_response,
-                                                    form_index=-1,
-                                                    inputs={'username': username,
-                                                            'password': password})
+        login_response = self._request("GET", "https://www.eso.org/sso/login",
+                                       cache=False)
+        login_result_response = self._activate_form(
+            login_response, form_index=-1, inputs={'username': username,
+                                                   'password': password})
         root = BeautifulSoup(login_result_response.content, 'html5lib')
         authenticated = not root.select('.error')
         if authenticated:
@@ -191,9 +239,8 @@ class EsoClass(QueryWithLogin):
 
         """
         if self._instrument_list is None:
-            instrument_list_response = self._request("GET",
-                                                     "http://archive.eso.org/cms/eso-data/instrument-specific-query-forms.html",
-                                                     cache=cache)
+            url = "http://archive.eso.org/cms/eso-data/instrument-specific-query-forms.html"
+            instrument_list_response = self._request("GET", url, cache=cache)
             root = BeautifulSoup(instrument_list_response.content, 'html5lib')
             self._instrument_list = []
             for element in root.select("div[id=col3] a[href]"):
@@ -213,30 +260,34 @@ class EsoClass(QueryWithLogin):
         survey_list : list of strings
         cache : bool
             Cache the response for faster subsequent retrieval
-
         """
         if self._survey_list is None:
-            survey_list_response = self._request("GET",
-                                                 "http://archive.eso.org/wdb/wdb/adp/phase3_main/form",
-                                                 cache=cache)
-            root = BeautifulSoup(survey_list_response .content, 'html5lib')
+            survey_list_response = self._request(
+                "GET", "http://archive.eso.org/wdb/wdb/adp/phase3_main/form",
+                cache=cache)
+            root = BeautifulSoup(survey_list_response.content, 'html5lib')
             self._survey_list = []
-            for select in root.select("select[name=phase3_program]"):
-                for element in select.select('option'):
-                    survey = element.text.strip()
-                    if survey not in self._survey_list and 'Any' not in survey:
+            collections_table = root.find('table', id='collections_table')
+            other_collections = root.find('select', id='collection_name_option')
+            for element in (collections_table.findAll('input', type='checkbox') +
+                            other_collections.findAll('option')):
+                if 'value' in element.attrs:
+                    survey = element.attrs['value']
+                    if survey and survey not in self._survey_list and 'Any' not in survey:
                         self._survey_list.append(survey)
         return self._survey_list
 
-    def query_survey(self, survey, cache=True, **kwargs):
+    def query_surveys(self, surveys='', cache=True,
+                      help=False, open_form=False, **kwargs):
         """
         Query survey Phase 3 data contained in the ESO archive.
 
         Parameters
         ----------
-        survey : string
-            Name of the survey to query, one of the names returned by
-            `list_surveys()`.
+        survey : string or list
+            Name of the survey(s) to query.  Should beone or more of the names
+            returned by `list_surveys()`.  If specified as a string, should be
+            a comma-separated list of survey names.
         cache : bool
             Cache the response for faster subsequent retrieval
 
@@ -251,39 +302,37 @@ class EsoClass(QueryWithLogin):
 
         """
 
-        if survey not in self.list_surveys():
-            raise ValueError("Survey %s is not in the survey list." % survey)
         url = "http://archive.eso.org/wdb/wdb/adp/phase3_main/form"
-        survey_form = self._request("GET", url, cache=cache)
-        query_dict = kwargs
-        query_dict["wdbo"] = "csv/download"
-        query_dict['phase3_program'] = survey
-        if self.ROW_LIMIT >= 0:
-            query_dict["max_rows_returned"] = self.ROW_LIMIT
+        if open_form:
+            webbrowser.open(url)
+        elif help:
+            self._print_surveys_help(url, cache=cache)
         else:
-            query_dict["max_rows_returned"] = 10000
-        survey_response = self._activate_form(survey_form, form_index=0,
-                                              inputs=query_dict, cache=cache)
+            survey_form = self._request("GET", url, cache=cache)
+            query_dict = kwargs
+            query_dict["wdbo"] = "csv/download"
+            if isinstance(surveys, six.string_types):
+                surveys = surveys.split(",")
+            query_dict['collection_name'] = surveys
+            if self.ROW_LIMIT >= 0:
+                query_dict["max_rows_returned"] = self.ROW_LIMIT
+            else:
+                query_dict["max_rows_returned"] = 10000
+
+            survey_response = self._activate_form(survey_form, form_index=0,
+                                                  inputs=query_dict, cache=cache)
+
+            content = survey_response.content
+            # First line is always garbage
+            content = content.split(b'\n', 1)[1]
+            log.debug("Response content:\n{0}".format(content))
+            if _check_response(content):
+                table = Table.read(BytesIO(content), format="ascii.csv",
+                                   comment="^#")
+                return table
+            else:
+                warnings.warn("Query returned no results", NoResultsWarning)
 
-        content = survey_response.content
-        #First line is always garbage
-        content = content.split(b'\n',1)[1]
-        log.debug("Response content:\n{0}".format(content))
-        if _check_response(content):
-            try:
-                table = Table.read(BytesIO(content), format="ascii.csv", comment="^#")
-            except Exception as ex:
-                # astropy 0.3.2 raises an anonymous exception; this is
-                # intended to prevent that from causing real problems
-                if 'No reader defined' in ex.args[0]:
-                    table = Table.read(BytesIO(content), format="ascii",
-                                       delimiter=',', guess=False,
-                                       header_start=1)
-                else:
-                    raise ex
-            return table
-        else:
-            warnings.warn("Query returned no results")
 
     def query_instrument(self, instrument, column_filters={}, columns=[],
                          open_form=False, help=False, cache=True, **kwargs):
@@ -318,15 +367,18 @@ class EsoClass(QueryWithLogin):
 
         """
 
-        if instrument in ('feros','harps'):
+        if instrument in ('feros', 'harps'):
             url = 'http://archive.eso.org/wdb/wdb/eso/repro/form'
+        elif instrument == 'grond':
+            url = 'http://archive.eso.org/wdb/wdb/eso/eso_archive_main/form'
         else:
-            url = "http://archive.eso.org/wdb/wdb/eso/{0}/form".format(instrument)
+            url = ("http://archive.eso.org/wdb/wdb/eso/{0}/form"
+                   .format(instrument))
         table = None
         if open_form:
             webbrowser.open(url)
         elif help:
-            self._print_help(url, instrument)
+            self._print_instrument_help(url, instrument)
         else:
             instrument_form = self._request("GET", url, cache=cache)
             query_dict = {}
@@ -335,39 +387,34 @@ class EsoClass(QueryWithLogin):
             query_dict.update(kwargs)
             query_dict["wdbo"] = "csv/download"
 
-            # Default to returning the DP.ID since it is needed for header acquisition
+            # Default to returning the DP.ID since it is needed for header
+            # acquisition
             query_dict['tab_dp_id'] = (kwargs.pop('tab_dp_id')
                                        if 'tab_db_id' in kwargs
                                        else 'on')
 
+            if instrument == 'grond':
+                query_dict['instrument'] = "GROND"
+
             for k in columns:
                 query_dict["tab_" + k] = True
             if self.ROW_LIMIT >= 0:
                 query_dict["max_rows_returned"] = self.ROW_LIMIT
             else:
                 query_dict["max_rows_returned"] = 10000
-            instrument_response = self._activate_form(instrument_form,
-                                                      form_index=0,
-                                                      inputs=query_dict, cache=cache)
+            instrument_response = self._activate_form(
+                instrument_form, form_index=0, inputs=query_dict, cache=cache)
+
             content = instrument_response.content
-            #First line is always garbage
+            # First line is always garbage
             content = content.split(b'\n', 1)[1]
             log.debug("Response content:\n{0}".format(content))
             if _check_response(content):
-                try:
-                    table = Table.read(BytesIO(content), format="ascii.csv", comment='^#')
-                except Exception as ex:
-                    # astropy 0.3.2 raises an anonymous exception; this is
-                    # intended to prevent that from causing real problems
-                    if 'No reader defined' in ex.args[0]:
-                        table = Table.read(BytesIO(content), format="ascii",
-                                           delimiter=',')
-                    else:
-                        raise ex
+                table = Table.read(BytesIO(content), format="ascii.csv",
+                                   comment='^#')
                 return table
             else:
-                warnings.warn("Query returned no results")
-
+                warnings.warn("Query returned no results", NoResultsWarning)
 
     def get_headers(self, product_ids, cache=True):
         """
@@ -391,14 +438,15 @@ class EsoClass(QueryWithLogin):
             A table where: columns are header keywords, rows are product_ids.
 
         """
-        _schema_product_ids = schema.Schema(schema.Or(Column, [schema.Or(*six.string_types)]))
+        _schema_product_ids = schema.Schema(
+            schema.Or(Column, [schema.Or(*six.string_types)]))
         _schema_product_ids.validate(product_ids)
         # Get all headers
         result = []
         for dp_id in product_ids:
-            response = self._request("GET",
-                                     "http://archive.eso.org/hdr?DpId={0}".format(dp_id),
-                                     cache=cache)
+            response = self._request(
+                "GET", "http://archive.eso.org/hdr?DpId={0}".format(dp_id),
+                cache=cache)
             root = BeautifulSoup(response.content, 'html5lib')
             hdr = root.select('pre')[0].text
             header = {'DP.ID': dp_id}
@@ -504,34 +552,39 @@ class EsoClass(QueryWithLogin):
             else:
                 datasets_to_download.append(dataset)
 
-        valid_datasets = [self.verify_data_exists(ds) for ds in datasets_to_download]
+        valid_datasets = [self.verify_data_exists(ds)
+                          for ds in datasets_to_download]
         if not all(valid_datasets):
-            invalid_datasets = [ds for ds, v in zip(datasets_to_download, valid_datasets) if not v]
-            raise ValueError("The following data sets were not found on the ESO servers: {0}".format(invalid_datasets))
+            invalid_datasets = [ds for ds, v in zip(datasets_to_download,
+                                                    valid_datasets) if not v]
+            raise ValueError("The following data sets were not found on the "
+                             "ESO servers: {0}".format(invalid_datasets))
 
         # Second: Download the other datasets
         if datasets_to_download:
             if not self.authenticated():
                 self.login()
-            data_retrieval_form = self._request("GET",
-                                                "http://archive.eso.org/cms/eso-data/eso-data-direct-retrieval.html",
-                                                cache=cache)
+            url = "http://archive.eso.org/cms/eso-data/eso-data-direct-retrieval.html"
+            data_retrieval_form = self._request("GET", url, cache=cache)
             log.info("Staging request...")
             with suspend_cache(self):  # Never cache staging operations
                 inputs = {"list_of_datasets": "\n".join(datasets_to_download)}
-                data_confirmation_form = self._activate_form(data_retrieval_form,
-                                                             form_index=-1,
-                                                             inputs=inputs)
-                root = BeautifulSoup(data_confirmation_form.content, 'html5lib')
+                data_confirmation_form = self._activate_form(
+                    data_retrieval_form, form_index=-1, inputs=inputs)
+
+                root = BeautifulSoup(data_confirmation_form.content,
+                                     'html5lib')
                 login_button = root.select('input[value=LOGIN]')
                 if login_button:
-                    raise LoginError("Not logged in."
-                                     "  You must be logged in to download data.")
+                    raise LoginError("Not logged in. "
+                                     "You must be logged in to download data.")
+
                 # TODO: There may be another screen for Not Authorized; that
                 # should be included too
-                data_download_form = self._activate_form(data_confirmation_form,
-                                                         form_index=-1)
-                log.info("Staging form is at {0}".format(data_download_form.url))
+                data_download_form = self._activate_form(
+                    data_confirmation_form, form_index=-1)
+                log.info("Staging form is at {0}."
+                         .format(data_download_form.url))
                 root = BeautifulSoup(data_download_form.content, 'html5lib')
                 state = root.select('span[id=requestState]')[0].text
                 t0 = time.time()
@@ -540,21 +593,26 @@ class EsoClass(QueryWithLogin):
                     data_download_form = self._request("GET",
                                                        data_download_form.url,
                                                        cache=False)
-                    root = BeautifulSoup(data_download_form.content, 'html5lib')
+                    root = BeautifulSoup(data_download_form.content,
+                                         'html5lib')
                     state = root.select('span[id=requestState]')[0].text
-                    print("{0:20.0f}s elapsed".format(time.time()-t0), end='\r')
+                    print("{0:20.0f}s elapsed"
+                          .format(time.time() - t0), end='\r')
                     sys.stdout.flush()
                 if state == 'ERROR':
-                    raise RemoteServiceError("There was a remote service error;"
-                                             " perhaps the requested file could not be found?")
+                    raise RemoteServiceError("There was a remote service "
+                                             "error; perhaps the requested "
+                                             "file could not be found?")
             log.info("Downloading files...")
             for fileId in root.select('input[name=fileId]'):
-                fileLink = "http://dataportal.eso.org/dataPortal"+fileId.attrs['value'].split()[1]
+                fileLink = ("http://dataportal.eso.org/dataPortal" +
+                            fileId.attrs['value'].split()[1])
                 filename = self._request("GET", fileLink, save=True)
                 files.append(system_tools.gunzip(filename))
-        self._session.redirect_cache.clear() # EMpty the redirect cache of this request session
+        # Empty the redirect cache of this request session
+        self._session.redirect_cache.clear()
         log.info("Done!")
-        if (not return_list) and (len(files)==1):
+        if (not return_list) and (len(files) == 1):
             files = files[0]
         return files
 
@@ -565,9 +623,9 @@ class EsoClass(QueryWithLogin):
         """
         url = 'http://archive.eso.org/wdb/wdb/eso/eso_archive_main/query'
         payload = {'dp_id': dataset,
-                   'ascii_out_mode':'true',
-                  }
-        # Never cache this check as it is verifying the existence of remote content
+                   'ascii_out_mode': 'true',
+                   }
+        # Never cache this as it is verifying the existence of remote content
         response = self._request("POST", url, params=payload, cache=False)
 
         content = response.text
@@ -593,50 +651,41 @@ class EsoClass(QueryWithLogin):
         if open_form:
             webbrowser.open(apex_query_url)
         elif help:
-            return self._print_help(apex_query_url, 'apex')
+            return self._print_instrument_help(apex_query_url, 'apex')
         else:
 
-            payload = {'wdbo':'csv/download'}
+            payload = {'wdbo': 'csv/download'}
             if project_id is not None:
-                payload['dp_id'] = project_id
+                payload['prog_id'] = project_id
             payload.update(kwargs)
 
             apex_form = self._request("GET", apex_query_url, cache=cache)
-            apex_response = self._activate_form(apex_form, form_index=0,
-                                                inputs=payload, cache=cache,
-                                                method='application/x-www-form-urlencoded')
+            apex_response = self._activate_form(
+                apex_form, form_index=0, inputs=payload, cache=cache,
+                method='application/x-www-form-urlencoded')
 
             content = apex_response.content
             if _check_response(content):
-                #First line is always garbage
-                content = content.split(b'\n',1)[1]
-                try:
-                    table = Table.read(BytesIO(content), format="ascii.csv",
-                                       guess=False,# header_start=1,
-                                       comment="#")
-                except Exception as ex:
-                    # astropy 0.3.2 raises an anonymous exception; this is
-                    # intended to prevent that from causing real problems
-                    if 'No reader defined' in ex.args[0]:
-                        table = Table.read(BytesIO(content), format="ascii",
-                                           delimiter=',', guess=False,
-                                           #header_start=1,
-                                           comment="#")
-                    else:
-                        raise ex
+                # First line is always garbage
+                content = content.split(b'\n', 1)[1]
+                table = Table.read(BytesIO(content), format="ascii.csv",
+                                   guess=False,  # header_start=1,
+                                   comment="#")
             else:
                 raise RemoteServiceError("Query returned no results")
 
             return table
 
-
-    def _print_help(self, url, instrument, cache=True):
+    def _print_instrument_help(self, url, instrument, cache=True):
         """
         Download a form and print it in a quasi-human-readable way
         """
-        log.info("List of the column_filters parameters accepted by the {0} instrument query.".format(instrument))
-        log.info("The presence of a column in the result table can be controlled if prefixed with a [ ] checkbox.")
-        log.info("The default columns in the result table are shown as already ticked: [x].")
+        log.info("List of the column_filters parameters accepted by the "
+                 "{0} instrument query.".format(instrument))
+        log.info("The presence of a column in the result table can be "
+                 "controlled if prefixed with a [ ] checkbox.")
+        log.info("The default columns in the result table are shown as "
+                 "already ticked: [x].")
 
         result_string = []
 
@@ -645,7 +694,8 @@ class EsoClass(QueryWithLogin):
         form = doc.select("html body form pre")[0]
         for section in form.select("table"):
             section_title = "".join(section.stripped_strings)
-            section_title = "\n".join(["", section_title, "-"*len(section_title)])
+            section_title = "\n".join(["", section_title,
+                                       "-" * len(section_title)])
             result_string.append(section_title)
             checkbox_name = ""
             checkbox_value = ""
@@ -664,7 +714,9 @@ class EsoClass(QueryWithLogin):
                 elif tag.name == u"select":
                     options = []
                     for option in tag.select("option"):
-                        options += ["{0} ({1})".format(option['value'], "".join(option.stripped_strings))]
+                        options += ["{0} ({1})"
+                                    .format(option['value'],
+                                            "".join(option.stripped_strings))]
                     name = tag[u"name"]
                     value = ", ".join(options)
                 else:
@@ -675,7 +727,90 @@ class EsoClass(QueryWithLogin):
                 else:
                     checkbox = "   "
                 if name != u"":
-                    result_string.append("{0} {1}: {2}".format(checkbox, name, value))
+                    result_string.append("{0} {1}: {2}"
+                                         .format(checkbox, name, value))
+
+        print("\n".join(result_string))
+        return result_string
+
+    def query_survey(self, **kwargs):
+        raise DeprecationWarning("query_survey is deprecated; use "
+                                 "query_surveys instead.  It should "
+                                 "accept the same arguments.")
+
+    def _print_surveys_help(self, url, cache=True):
+        """
+        Download a form and print it in a quasi-human-readable way
+        """
+        log.info("List of the parameters accepted by the "
+                 "surveys query.")
+        log.info("The presence of a column in the result table can be "
+                 "controlled if prefixed with a [ ] checkbox.")
+        log.info("The default columns in the result table are shown as "
+                 "already ticked: [x].")
+
+        result_string = []
+
+        resp = self._request("GET", url, cache=cache)
+        doc = BeautifulSoup(resp.content, 'html5lib')
+        form = doc.select("html body form")[0]
+
+        # hovertext from different labels are used to give more info on forms
+        helptext_dict = {abbr['title'].split(":")[0].strip():
+                         ":".join(abbr['title'].split(":")[1:])
+                         for abbr in form.findAll('abbr')
+                         if 'title' in abbr.attrs and ":" in abbr['title']}
+
+        for fieldset in form.select('fieldset'):
+            legend = fieldset.select('legend')
+            if len(legend) > 1:
+                raise ValueError("Form parsing error: too many legends.")
+            elif len(legend) == 0:
+                continue
+            section_title = "\n\n"+"".join(legend[0].stripped_strings)+"\n"
+
+            result_string.append(section_title)
+
+            for section in fieldset.select('table'):
+
+                checkbox_name = ""
+                checkbox_value = ""
+                for tag in section.next_elements:
+                    if tag.name == u"table":
+                        break
+                    elif tag.name == u"input":
+                        if tag.get(u'type') == u"checkbox":
+                            checkbox_name = tag['name']
+                            checkbox_value = (u"[x]"
+                                              if ('checked' in tag.attrs)
+                                              else u"[ ]")
+                            name = ""
+                            value = ""
+                        else:
+                            name = tag['name']
+                            value = ""
+                    elif tag.name == u"select":
+                        options = []
+                        for option in tag.select("option"):
+                            options += ["{0} ({1})"
+                                        .format(option['value']
+                                                if 'value' in option
+                                                else "",
+                                                "".join(option.stripped_strings))]
+                        name = tag[u"name"]
+                        value = ", ".join(options)
+                    else:
+                        name = ""
+                        value = ""
+                    if u"tab_" + name == checkbox_name:
+                        checkbox = checkbox_value
+                    else:
+                        checkbox = "   "
+                    if name != u"":
+                        result_string.append("{0} {1}: {2}"
+                                             .format(checkbox, name, value))
+                        if name.strip() in helptext_dict:
+                            result_string.append(helptext_dict[name.strip()])
 
         print("\n".join(result_string))
         return result_string
