@@ -1,16 +1,8 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 import os
-from distutils.version import LooseVersion
-import astropy
-try:
-    from ...eso import Eso
-    ESO_IMPORTED = True
-except ImportError:
-    ESO_IMPORTED = False
-from astropy.tests.helper import pytest
 from ...utils.testing_tools import MockResponse
 
-SKIP_TESTS = not ESO_IMPORTED
+from ...eso import Eso
 
 DATA_DIR = os.path.join(os.path.dirname(__file__), 'data')
 
@@ -22,12 +14,12 @@ DATA_FILES = {'GET': {'http://archive.eso.org/wdb/wdb/eso/amber/form':
                       'amber_form.html',
                       'http://archive.eso.org/wdb/wdb/adp/phase3_main/form':
                       'vvv_sgra_form.html',
-                     },
+                      },
               'POST': {'http://archive.eso.org/wdb/wdb/eso/amber/query':
                        'amber_sgra_query.tbl',
                        'http://archive.eso.org/wdb/wdb/adp/phase3_main/query':
                        'vvv_sgra_survey_response.tbl',
-                      }
+                       }
               }
 
 
@@ -46,7 +38,6 @@ def eso_request(request_type, url, **kwargs):
 # This test should attempt to access the internet and therefore should fail
 # (_activate_form always connects to the internet)
 # @pytest.mark.xfail
-@pytest.mark.skipif('SKIP_TESTS')
 def test_SgrAstar(monkeypatch):
     # Local caching prevents a remote query here
 
@@ -64,13 +55,16 @@ def test_SgrAstar(monkeypatch):
     assert len(result) == 50
     assert 'GC_IRS7' in result['Object']
 
-@pytest.mark.skipif('SKIP_TESTS')
+
 def test_vvv(monkeypatch):
     eso = Eso()
     monkeypatch.setattr(eso, '_request', eso_request)
     eso.cache_location = DATA_DIR
 
-    result_s = eso.query_survey('VVV', coord1=266.41681662, coord2=-29.00782497)
+    result_s = eso.query_surveys('VVV',
+                                 coord1=266.41681662, coord2=-29.00782497,
+                                 box='01 00 00',
+                                )
     assert result_s is not None
     assert 'Object' in result_s.colnames
     assert 'b333' in result_s['Object']
