@@ -49,11 +49,13 @@ def patch_get(request):
 @pytest.fixture
 def patch_get_readable_fileobj(request):
     def get_readable_fileobj_mockreturn(filename, cache=True, encoding=None):
-        # Need to read FITS files with binary encoding: should raise error otherwise
+        # Need to read FITS files with binary encoding: should raise error
+        # otherwise
         assert encoding == 'binary'
         return open(data_path(DATA_FILES['image']), 'rb')
     mp = request.getfuncargvalue("monkeypatch")
-    mp.setattr(commons, 'get_readable_fileobj', get_readable_fileobj_mockreturn)
+    mp.setattr(commons, 'get_readable_fileobj',
+               get_readable_fileobj_mockreturn)
     return mp
 
 
@@ -92,16 +94,18 @@ def test_get_references_async(patch_get):
     assert response['search_type'] == 'Reference'
 
 
-@pytest.mark.xfail(reason="astropy issue #1266")
 def test_get_references(patch_get):
-    response = ned.core.Ned.get_table_async("m1", table='references', from_year=2010)
+    response = ned.core.Ned.get_table_async(
+        "m1", table='references', from_year=2010)
     assert response is not None
-    result = ned.core.Ned.get_table("m1", table='references', to_year=2012, extended_search=True)
+    result = ned.core.Ned.get_table(
+        "m1", table='references', to_year=2012, extended_search=True)
     assert isinstance(result, Table)
 
 
 def test_get_positions_async(patch_get):
-    response = ned.core.Ned.get_table_async("m1", table='positions', get_query_payload=True)
+    response = ned.core.Ned.get_table_async(
+        "m1", table='positions', get_query_payload=True)
     assert response['objname'] == 'm1'
     response = ned.core.Ned.get_table_async("m1", table='positions')
     assert response is not None
@@ -113,7 +117,8 @@ def test_get_positions(patch_get):
 
 
 def test_get_redshifts_async(patch_get):
-    response = ned.core.Ned.get_table_async("3c 273", table='redshifts', get_query_payload=True)
+    response = ned.core.Ned.get_table_async(
+        "3c 273", table='redshifts', get_query_payload=True)
     assert response['objname'] == '3c 273'
     assert response['search_type'] == 'Redshifts'
     response = ned.core.Ned.get_table_async("3c 273", table='redshifts')
@@ -126,7 +131,8 @@ def test_get_redshifts(patch_get):
 
 
 def test_get_photometry_async(patch_get):
-    response = ned.core.Ned.get_table_async("3c 273", table='photometry', get_query_payload=True)
+    response = ned.core.Ned.get_table_async(
+        "3c 273", table='photometry', get_query_payload=True)
     assert response['objname'] == '3c 273'
     assert response['meas_type'] == 'bot'
     assert response['search_type'] == 'Photometry'
@@ -190,7 +196,8 @@ def test_query_refcode(patch_get):
 
 
 def test_query_region_iau_async(patch_get):
-    response = ned.core.Ned.query_region_iau_async('1234-423', get_query_payload=True)
+    response = ned.core.Ned.query_region_iau_async(
+        '1234-423', get_query_payload=True)
     assert response['search_type'] == 'IAU Search'
     assert response['iau_name'] == '1234-423'
     assert response['in_csys'] == 'Equatorial'
@@ -205,28 +212,33 @@ def test_query_region_iau(patch_get):
 
 
 def mock_check_resolvable(name):
-        if name != 'm1':
-            raise coord.name_resolve.NameResolveError
+    if name != 'm1':
+        raise coord.name_resolve.NameResolveError
 
 
 def test_query_region_async(monkeypatch, patch_get):
     # check with the name
-    monkeypatch.setattr(coord.name_resolve, 'get_icrs_coordinates', mock_check_resolvable)
+    monkeypatch.setattr(
+        coord.name_resolve, 'get_icrs_coordinates', mock_check_resolvable)
     response = ned.core.Ned.query_region_async("m1", get_query_payload=True)
     assert response['objname'] == "m1"
     assert response['search_type'] == "Near Name Search"
     # check with Galactic coordinates
-    response = ned.core.Ned.query_region_async(commons.GalacticCoordGenerator(l=-67.02084, b=-29.75447, unit=(u.deg, u.deg)),
-                                               get_query_payload=True)
+    response = ned.core.Ned.query_region_async(
+        commons.GalacticCoordGenerator(l=-67.02084, b=-29.75447,
+                                       unit=(u.deg, u.deg)),
+        get_query_payload=True)
     assert response['search_type'] == 'Near Position Search'
-    npt.assert_approx_equal(response['lon'] % 360, -67.02084 % 360, significant=5)
+    npt.assert_approx_equal(
+        response['lon'] % 360, -67.02084 % 360, significant=5)
     npt.assert_approx_equal(response['lat'], -29.75447, significant=5)
     response = ned.core.Ned.query_region_async("05h35m17.3s +22d00m52.2s")
     assert response is not None
 
 
 def test_query_region(monkeypatch, patch_get):
-    monkeypatch.setattr(coord.name_resolve, 'get_icrs_coordinates', mock_check_resolvable)
+    monkeypatch.setattr(
+        coord.name_resolve, 'get_icrs_coordinates', mock_check_resolvable)
     result = ned.core.Ned.query_region("m1")
     assert isinstance(result, Table)
 
@@ -244,7 +256,8 @@ def test_query_object(patch_get):
 
 
 def test_get_object_notes_async(patch_get):
-    response = ned.core.Ned.get_table_async('m1', table='object_notes', get_query_payload=True)
+    response = ned.core.Ned.get_table_async(
+        'm1', table='object_notes', get_query_payload=True)
     assert response['objname'] == 'm1'
     assert response['search_type'] == 'Notes'
     response = ned.core.Ned.get_table_async('m1', table='object_notes')
@@ -262,6 +275,10 @@ def test_parse_result(capsys):
     with pytest.raises(RemoteServiceError) as exinfo:
         ned.core.Ned._parse_result(response)
     if hasattr(exinfo.value, 'message'):
-        assert exinfo.value.message == "The remote service returned the following error message.\nERROR:  No note found."
+        assert exinfo.value.message == ("The remote service returned the "
+                                        "following error message.\nERROR:  "
+                                        "No note found.")
     else:
-        assert exinfo.value.args == ("The remote service returned the following error message.\nERROR:  No note found.",)
+        assert exinfo.value.args == ("The remote service returned the "
+                                     "following error message.\nERROR:  "
+                                     "No note found.",)
