@@ -5,14 +5,13 @@ import abc
 import pickle
 import hashlib
 import os
-import warnings
 import requests
-import itertools
 
 from astropy.extern import six
 from astropy.config import paths
 from astropy import log
-from astropy.utils.console import ProgressBar,ProgressBarOrSpinner
+import astropy.units as u
+from astropy.utils.console import ProgressBarOrSpinner
 import astropy.utils.data
 
 from . import version
@@ -100,11 +99,14 @@ class BaseQuery(object):
 
     def __init__(self):
         S = self._session = requests.session()
-        S.headers['User-Agent'] = ('astroquery/{vers} {olduseragent}'
-                                   .format(vers=version.version,
-                                           olduseragent=S.headers['User-Agent']))
-        self.cache_location = os.path.join(paths.get_cache_dir(), 'astroquery',
-                                           self.__class__.__name__.split("Class")[0])
+        S.headers['User-Agent'] = (
+            'astroquery/{vers} {olduseragent}'
+            .format(vers=version.version,
+                    olduseragent=S.headers['User-Agent']))
+
+        self.cache_location = os.path.join(
+            paths.get_cache_dir(), 'astroquery',
+            self.__class__.__name__.split("Class")[0])
         if not os.path.exists(self.cache_location):
             os.makedirs(self.cache_location)
         self._cache_active = True
@@ -117,8 +119,8 @@ class BaseQuery(object):
                  files=None, save=False, savedir='', timeout=None, cache=True,
                  stream=False, auth=None):
         """
-        A generic HTTP request method, similar to `requests.Session.request` but
-        with added caching-related tools
+        A generic HTTP request method, similar to `requests.Session.request`
+        but with added caching-related tools
 
         This is a low-level method not generally intended for use by astroquery
         end-users.  As such, it is likely to be renamed to, e.g., `_request` in
@@ -154,15 +156,16 @@ class BaseQuery(object):
             local_filename = url.split('/')[-1]
             local_filepath = os.path.join(self.cache_location or savedir or
                                           '.', local_filename)
-            log.info("Downloading {0}...".format(local_filename))
+            # REDUNDANT: spinner has this log.info("Downloading
+            # {0}...".format(local_filename))
             self._download_file(url, local_filepath, timeout=timeout,
-                                auth=auth)
+                                auth=auth, cache=cache)
             return local_filepath
         else:
             query = AstroQuery(method, url, params=params, data=data,
                                headers=headers, files=files, timeout=timeout)
             if ((self.cache_location is None) or (not self._cache_active) or
-                (not cache)):
+                    (not cache)):
                 with suspend_cache(self):
                     response = query.request(self._session, stream=stream,
                                              auth=auth)
@@ -176,30 +179,53 @@ class BaseQuery(object):
                     to_cache(response, query.request_file(self.cache_location))
             return response
 
-    def _download_file(self, url, local_filepath, timeout=None, auth=None):
+    def _download_file(self, url, local_filepath, timeout=None, auth=None,
+                       cache=False):
         """
         Download a file.  Resembles `astropy.utils.data.download_file` but uses
         the local ``_session``
         """
         response = self._session.get(url, timeout=timeout, stream=True,
-                                      auth=auth)
+                                     auth=auth)
+        response.raise_for_status()
         if 'content-length' in response.headers:
             length = int(response.headers['content-length'])
         else:
             length = None
 
+        if cache and os.path.exists(local_filepath):
+            if length is not None:
+                statinfo = os.stat(local_filepath)
+                if statinfo.st_size != length:
+                    log.warn("Found cached file {0} with size {1} that is "
+                             "different from expected size {2}"
+                             .format(local_filepath,
+                                     statinfo.st_size,
+                                     length))
+                else:
+                    log.info("Found cached file {0} with expected size {1}."
+                             .format(local_filepath, statinfo.st_size))
+                    response.close()
+                    return
+            else:
+                log.info("Found cached file {0}.".format(local_filepath))
+                response.close()
+                return
+
         blocksize = astropy.utils.data.conf.download_block_size
 
         bytes_read = 0
 
-        with ProgressBarOrSpinner(length,
-                                  'Downloading URL {0} ...'.format(url)) as pb:
+        with ProgressBarOrSpinner(
+            length, ('Downloading URL {0} to {1} ...'
+                     .format(url, local_filepath))) as pb:
             with open(local_filepath, 'wb') as f:
                 for block in response.iter_content(blocksize):
                     f.write(block)
                     bytes_read += blocksize
                     if length is not None:
-                        pb.update(bytes_read if bytes_read <= length else length)
+                        pb.update(bytes_read if bytes_read <= length else
+                                  length)
                     else:
                         pb.update(bytes_read)
 
@@ -210,6 +236,7 @@ class suspend_cache:
     """
     A context manager that suspends caching.
     """
+
     def __init__(self, obj):
         self.obj = obj
 
