@@ -1,86 +1,201 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 """
-
-Author: Jordan Mirocha
-Affiliation: University of Colorado at Boulder
-Created on: Sun Apr 14 19:18:43 2013
-
-Description: Access Sloan Digital Sky Survey database online.
-
+Access Sloan Digital Sky Survey database online.
 """
-
-from __future__ import print_function
+from __future__ import (absolute_import, division, print_function,
+                        unicode_literals)
 import io
+import warnings
 import numpy as np
+
 from astropy import units as u
 import astropy.coordinates as coord
-from astropy.table import Table
+from astropy.table import Table, Column
+
 from ..query import BaseQuery
 from . import conf
 from ..utils import commons, async_to_sync
 from ..utils.docstr_chompers import prepend_docstr_noreturns
-from ..exceptions import RemoteServiceError
+from ..exceptions import RemoteServiceError, NoResultsWarning
+from .field_names import (photoobj_defs, specobj_defs,
+                          crossid_defs, get_field_info)
 
 __all__ = ['SDSS', 'SDSSClass']
-
 __doctest_skip__ = ['SDSSClass.*']
 
-# Default photometric and spectroscopic quantities to retrieve.
-photoobj_defs = ['ra', 'dec', 'objid', 'run', 'rerun', 'camcol', 'field']
-specobj_defs = ['z', 'plate', 'mjd', 'fiberID', 'specobjid', 'run2d',
-                'instrument']
 
-# Cross-correlation templates from DR-7
-spec_templates = {'star_O': 0, 'star_OB': 1, 'star_B': 2, 'star_A': [3, 4],
-                  'star_FA': 5, 'star_F': [6, 7], 'star_G': [8, 9],
-                  'star_K': 10, 'star_M1': 11, 'star_M3': 12, 'star_M5': 13,
-                  'star_M8': 14, 'star_L1': 15, 'star_wd': [16, 20, 21],
-                  'star_carbon': [17, 18, 19], 'star_Ksubdwarf': 22,
-                  'galaxy_early': 23, 'galaxy': [24, 25, 26],
-                  'galaxy_late': 27, 'galaxy_lrg': 28, 'qso': 29,
-                  'qso_bal': [30, 31], 'qso_bright': 32
-                  }
-
-sdss_arcsec_per_pixel = 0.396
+sdss_arcsec_per_pixel = 0.396 * u.arcsec / u.pixel
 
 
 @async_to_sync
 class SDSSClass(BaseQuery):
-
-    BASE_URL = conf.server
-    SPECTRO_OPTICAL = BASE_URL
-    IMAGING = BASE_URL + '/boss/photoObj/frames'
-    TEMPLATES = 'http://classic.sdss.org/dr7/algorithms/spectemplates/spDR2'
-    MAXQUERIES = conf.maxqueries
-    AVAILABLE_TEMPLATES = spec_templates
     TIMEOUT = conf.timeout
+    QUERY_URL_SUFFIX_DR_OLD = '/dr{dr}/en/tools/search/x_sql.asp'
+    QUERY_URL_SUFFIX_DR_10 = '/dr{dr}/en/tools/search/x_sql.aspx'
+    QUERY_URL_SUFFIX_DR_NEW = '/dr{dr}/en/tools/search/x_results.aspx'
+    XID_URL_SUFFIX_OLD = '/dr{dr}/en/tools/crossid/x_crossid.aspx'
+    XID_URL_SUFFIX_NEW = '/dr{dr}/en/tools/search/X_Results.aspx'
+    IMAGING_URL_SUFFIX = ('{base}/dr{dr}/boss/photoObj/frames/'
+                          '{rerun}/{run}/{camcol}/'
+                          'frame-{band}-{run:06d}-{camcol}-'
+                          '{field:04d}.fits.bz2')
+    SPECTRA_URL_SUFFIX = ('{base}/dr{dr}/{instrument}/spectro/redux/'
+                          '{run2d}/spectra/{plate:04d}/'
+                          'spec-{plate:04d}-{mjd}-{fiber:04d}.fits')
 
-    QUERY_URL = 'http://skyserver.sdss3.org/public/en/tools/search/x_sql.aspx'
+    TEMPLATES_URL = 'http://classic.sdss.org/dr7/algorithms/spectemplates/spDR2'
+    # Cross-correlation templates from DR-7 - no clear way to look this up via
+    # queries so we just name them explicitly here
+    AVAILABLE_TEMPLATES = {'star_O': 0, 'star_OB': 1, 'star_B': 2,
+                           'star_A': [3, 4], 'star_FA': 5, 'star_F': [6, 7],
+                           'star_G': [8, 9], 'star_K': 10, 'star_M1': 11,
+                           'star_M3': 12, 'star_M5': 13, 'star_M8': 14,
+                           'star_L1': 15, 'star_wd': [16, 20, 21],
+                           'star_carbon': [17, 18, 19], 'star_Ksubdwarf': 22,
+                           'galaxy_early': 23, 'galaxy': [24, 25, 26],
+                           'galaxy_late': 27, 'galaxy_lrg': 28, 'qso': 29,
+                           'qso_bal': [30, 31], 'qso_bright': 32
+                           }
 
-    def query_region_async(self, coordinates, radius=u.degree / 1800.,
+    def query_crossid_async(self, coordinates, obj_names=None,
+                            photoobj_fields=None, specobj_fields=None,
+                            get_query_payload=False, timeout=TIMEOUT,
+                            radius=5. * u.arcsec, data_release=12, cache=True):
+        """
+        Query using the cross-identification web interface.
+
+        Parameters
+        ----------
+        coordinates : str or `astropy.coordinates` object or list of
+            coordinates or `~astropy.table.Column` of coordinates The
+            target(s) around which to search. It may be specified as a
+            string in which case it is resolved using online services or as
+            the appropriate `astropy.coordinates` object. ICRS coordinates
+            may also be entered as strings as specified in the
+            `astropy.coordinates` module.
+
+            Example:
+            ra = np.array([220.064728084,220.064728467,220.06473483])
+            dec = np.array([0.870131920218,0.87013210119,0.870138329659])
+            coordinates = SkyCoord(ra, dec, frame='icrs', unit='deg')
+        radius : str or `~astropy.units.Quantity` object, optional The
+            string must be parsable by `~astropy.coordinates.Angle`. The
+            appropriate `~astropy.units.Quantity` object from
+            `astropy.units` may also be used. Defaults to 2 arcsec.
+        timeout : float, optional
+            Time limit (in seconds) for establishing successful connection with
+            remote server.  Defaults to `SDSSClass.TIMEOUT`.
+        photoobj_fields : float, optional
+            PhotoObj quantities to return. If photoobj_fields is None and
+            specobj_fields is None then the value of fields is used
+        specobj_fields : float, optional
+            SpecObj quantities to return. If photoobj_fields is None and
+            specobj_fields is None then the value of fields is used
+        obj_names : str, or list or `~astropy.table.Column`, optional
+            Target names. If given, every coordinate should have a
+            corresponding name, and it gets repeated in the query result.
+            It generates unique object names by default.
+        get_query_payload : bool
+            If True, this will return the data the query would have sent out,
+            but does not actually do the query.
+        data_release : int
+            The data release of the SDSS to use.
+        """
+
+        if (not isinstance(coordinates, list) and
+                not isinstance(coordinates, Column) and
+                not (isinstance(coordinates, commons.CoordClasses) and
+                     not coordinates.isscalar)):
+            coordinates = [coordinates]
+
+        if obj_names is None:
+            obj_names = ['obj_{0}'.format(i) for i in range(len(coordinates))]
+        elif len(obj_names) != len(coordinates):
+            raise ValueError("Number of coordinates and obj_names should "
+                             "be equal")
+
+        if isinstance(radius, u.Quantity):
+            radius = radius.to(u.arcmin).value
+        else:
+            try:
+                float(radius)
+            except TypeError:
+                raise TypeError("radius should be either Quantity or "
+                                "convertible to float.")
+
+        sql_query = 'SELECT '
+
+        if specobj_fields is None:
+            if photoobj_fields is None:
+                photoobj_fields = crossid_defs
+            photobj_fields = ['p.{0}'.format(i) for i in photoobj_fields]
+            photobj_fields.append('p.objID as obj_id')
+            specobj_fields = []
+        else:
+            specobj_fields = ['s.{0}'.format(i) for i in specobj_fields]
+            if photoobj_fields is not None:
+                photobj_fields = ['p.{0}'.format(i) for i in photoobj_fields]
+                photobj_fields.append('p.objID as obj_id')
+            else:
+                photobj_fields = []
+                specobj_fields.append('s.objID as obj_id')
+
+        sql_query += ', '.join(photobj_fields + specobj_fields)
+
+        sql_query += ',dbo.fPhotoTypeN(p.type) as type \
+                      FROM #upload u JOIN #x x ON x.up_id = u.up_id \
+                      JOIN PhotoObjAll p ON p.objID = x.objID ORDER BY x.up_id'
+
+        data = "obj_id ra dec \n"
+        data += " \n ".join(['{0} {1} {2}'.format(obj_names[i],
+                                                  coordinates[i].ra.deg,
+                                                  coordinates[i].dec.deg)
+                             for i in range(len(coordinates))])
+
+        # firstcol is hardwired, as obj_names is always passed
+        request_payload = dict(uquery=sql_query, paste=data,
+                               firstcol=1,
+                               format='csv', photoScope='nearPrim',
+                               radius=radius,
+                               photoUpType='ra-dec', searchType='photo')
+
+        if data_release > 11:
+            request_payload['searchtool'] = 'CrossID'
+
+        if get_query_payload:
+            return request_payload
+        url = self._get_crossid_url(data_release)
+        response = self._request("POST", url, params=request_payload,
+                                 timeout=timeout, cache=cache)
+        return response
+
+    def query_region_async(self, coordinates, radius=2. * u.arcsec,
                            fields=None, spectro=False, timeout=TIMEOUT,
-                           get_query_payload=False, photoobj_fields=None, specobj_fields=None):
+                           get_query_payload=False, photoobj_fields=None,
+                           specobj_fields=None, field_help=False,
+                           obj_names=None, data_release=12, cache=True):
         """
         Used to query a region around given coordinates. Equivalent to
         the object cross-ID from the web interface.
 
         Parameters
         ----------
-        coordinates : str or `astropy.coordinates` object or list of coordinates
-            The target(s) around which to search. It may be specified as a string
-            in which case it is resolved using online services or as the
-            appropriate `astropy.coordinates` object. ICRS coordinates may also
-            be entered as strings as specified in the `astropy.coordinates`
-            module.
+        coordinates : str or `astropy.coordinates` object or list of
+            coordinates or `~astropy.table.Column` of coordinates The
+            target(s) around which to search. It may be specified as a
+            string in which case it is resolved using online services or as
+            the appropriate `astropy.coordinates` object. ICRS coordinates
+            may also be entered as strings as specified in the
+            `astropy.coordinates` module.
 
             Example:
             ra = np.array([220.064728084,220.064728467,220.06473483])
             dec = np.array([0.870131920218,0.87013210119,0.870138329659])
             coordinates = SkyCoord(ra, dec, frame='icrs', unit='deg')
-        radius : str or `~astropy.units.Quantity` object, optional
-            The string must be parsable by `~astropy.coordinates.Angle`. The
-            appropriate `~astropy.units.Quantity` object from `astropy.units` may also be
-            used. Defaults to 2 arcsec.
+        radius : str or `~astropy.units.Quantity` object, optional The
+            string must be parsable by `~astropy.coordinates.Angle`. The
+            appropriate `~astropy.units.Quantity` object from
+            `astropy.units` may also be used. Defaults to 2 arcsec.
         fields : list, optional
             SDSS PhotoObj or SpecObj quantities to return. If None, defaults
             to quantities required to find corresponding spectra and images
@@ -99,6 +214,18 @@ class SDSSClass(BaseQuery):
         specobj_fields : float, optional
             SpecObj quantities to return. If photoobj_fields is None and
             specobj_fields is None then the value of fields is used
+        field_help: str or bool, optional
+            Field name to check whether a valid PhotoObjAll or SpecObjAll
+            field name. If `True` or it is an invalid field name all the valid
+            field names are returned as a dict.
+        obj_names : str, or list or `~astropy.table.Column`, optional
+            Target names. If given, every coordinate should have a
+            corresponding name, and it gets repeated in the query result.
+        get_query_payload : bool
+            If True, this will return the data the query would have sent out,
+            but does not actually do the query.
+        data_release : int
+            The data release of the SDSS to use.
 
         Examples
         --------
@@ -121,20 +248,23 @@ class SDSSClass(BaseQuery):
             The result of the query as a `~astropy.table.Table` object.
 
         """
-        request_payload = self._args_to_payload(coordinates=coordinates,
-                                                radius=radius, fields=fields,
-                                                spectro=spectro, photoobj_fields=photoobj_fields,
-                                                specobj_fields=specobj_fields)
-        if get_query_payload:
+        request_payload = self._args_to_payload(
+            coordinates=coordinates, radius=radius, fields=fields,
+            spectro=spectro, photoobj_fields=photoobj_fields,
+            specobj_fields=specobj_fields, field_help=field_help,
+            obj_names=obj_names, data_release=data_release)
+        if get_query_payload or field_help:
             return request_payload
-        r = commons.send_request(SDSS.QUERY_URL, request_payload, timeout,
-                                 request_type='GET')
 
-        return r
+        url = self._get_query_url(data_release)
+        response = self._request("GET", url, params=request_payload,
+                                 timeout=timeout, cache=cache)
+        return response
 
     def query_specobj_async(self, plate=None, mjd=None, fiberID=None,
                             fields=None, timeout=TIMEOUT,
-                            get_query_payload=False):
+                            get_query_payload=False, field_help=False,
+                            data_release=12, cache=True):
         """
         Used to query the SpecObjAll table with plate, mjd and fiberID values.
 
@@ -157,6 +287,15 @@ class SDSSClass(BaseQuery):
         timeout : float, optional
             Time limit (in seconds) for establishing successful connection with
             remote server.  Defaults to `SDSSClass.TIMEOUT`.
+        field_help: str or bool, optional
+            Field name to check whether a valid PhotoObjAll or SpecObjAll
+            field name. If `True` or it is an invalid field name all the valid
+            field names are returned as a dict.
+        get_query_payload : bool
+            If True, this will return the data the query would have sent out,
+            but does not actually do the query.
+        data_release : int
+            The data release of the SDSS to use.
 
         Examples
         --------
@@ -183,18 +322,23 @@ class SDSSClass(BaseQuery):
             raise ValueError('must specify at least one of '
                              '`plate`, `mjd` or `fiberID`')
         request_payload = self._args_to_payload(plate=plate, mjd=mjd,
-                                                fiberID=fiberID, fields=fields,
-                                                spectro=True)
-        if get_query_payload:
+                                                fiberID=fiberID,
+                                                specobj_fields=fields,
+                                                spectro=True,
+                                                field_help=field_help,
+                                                data_release=data_release)
+        if get_query_payload or field_help:
             return request_payload
-        r = commons.send_request(SDSS.QUERY_URL, request_payload, timeout,
-                                 request_type='GET')
 
-        return r
+        url = self._get_query_url(data_release)
+        response = self._request("GET", url, params=request_payload,
+                                 timeout=timeout, cache=cache)
+        return response
 
     def query_photoobj_async(self, run=None, rerun=301, camcol=None,
                              field=None, fields=None, timeout=TIMEOUT,
-                             get_query_payload=False):
+                             get_query_payload=False, field_help=False,
+                             data_release=12, cache=True):
         """
         Used to query the PhotoObjAll table with run, rerun, camcol and field
         values.
@@ -221,6 +365,15 @@ class SDSSClass(BaseQuery):
         timeout : float, optional
             Time limit (in seconds) for establishing successful connection with
             remote server.  Defaults to `SDSSClass.TIMEOUT`.
+        field_help: str or bool, optional
+            Field name to check whether a valid PhotoObjAll or SpecObjAll
+            field name. If `True` or it is an invalid field name all the valid
+            field names are returned as a dict.
+        get_query_payload : bool
+            If True, this will return the data the query would have sent out,
+            but does not actually do the query.
+        data_release : int
+            The data release of the SDSS to use.
 
         Examples
         --------
@@ -247,13 +400,17 @@ class SDSSClass(BaseQuery):
                              '`run`, `camcol` or `field`')
         request_payload = self._args_to_payload(run=run, rerun=rerun,
                                                 camcol=camcol, field=field,
-                                                fields=fields, spectro=False)
-        if get_query_payload:
+                                                photoobj_fields=fields,
+                                                spectro=False,
+                                                field_help=field_help,
+                                                data_release=data_release)
+        if get_query_payload or field_help:
             return request_payload
-        r = commons.send_request(SDSS.QUERY_URL, request_payload, timeout,
-                                 request_type='GET')
 
-        return r
+        url = self._get_query_url(data_release)
+        response = self._request("GET", url, params=request_payload,
+                                 timeout=timeout, cache=cache)
+        return response
 
     def __sanitize_query(self, stmt):
         """Remove comments and newlines from SQL statement."""
@@ -262,7 +419,8 @@ class SDSSClass(BaseQuery):
             fsql += ' ' + line.split('--')[0]
         return fsql
 
-    def query_sql_async(self, sql_query, timeout=TIMEOUT, **kwargs):
+    def query_sql_async(self, sql_query, timeout=TIMEOUT, data_release=12,
+                        cache=True, **kwargs):
         """
         Query the SDSS database.
 
@@ -270,6 +428,11 @@ class SDSSClass(BaseQuery):
         ----------
         sql_query : str
             An SQL query
+        timeout : float, optional
+            Time limit (in seconds) for establishing successful connection with
+            remote server.  Defaults to `SDSSClass.TIMEOUT`.
+        data_release : int
+            The data release of the SDSS to use.
 
         Examples
         --------
@@ -299,16 +462,23 @@ class SDSSClass(BaseQuery):
 
         """
 
-        request_payload = dict(cmd=self.__sanitize_query(sql_query), format='csv')
+        request_payload = dict(cmd=self.__sanitize_query(sql_query),
+                               format='csv')
+        if data_release > 11:
+            request_payload['searchtool'] = 'SQL'
+
         if kwargs.get('get_query_payload'):
             return request_payload
-        r = commons.send_request(SDSS.QUERY_URL, request_payload, timeout,
-                                 request_type='GET')
-        return r
 
-    def get_spectra_async(self, coordinates=None, radius=u.degree / 1800.,
+        url = self._get_query_url(data_release)
+        response = self._request("GET", url, params=request_payload,
+                                 timeout=timeout, cache=cache)
+        return response
+
+    def get_spectra_async(self, coordinates=None, radius=2. * u.arcsec,
                           matches=None, plate=None, fiberID=None, mjd=None,
-                          timeout=TIMEOUT, get_query_payload=False):
+                          timeout=TIMEOUT, get_query_payload=False,
+                          data_release=12, cache=True):
         """
         Download spectrum from SDSS.
 
@@ -345,10 +515,17 @@ class SDSSClass(BaseQuery):
         timeout : float, optional
             Time limit (in seconds) for establishing successful connection with
             remote server.  Defaults to `SDSSClass.TIMEOUT`.
+        get_query_payload : bool
+            If True, this will return the data the query would have sent out,
+            but does not actually do the query.
+        data_release : int
+            The data release of the SDSS to use. With the default server, this
+            only supports DR8 or later.
 
         Returns
         -------
-        list : A list of context-managers that yield readable file-like objects.
+        list : list
+            A list of context-managers that yield readable file-like objects.
             The function returns the spectra for only one of ``matches``, or
             ``coordinates`` and ``radius``, or ``plate``, ``mjd`` and
             ``fiberID``.
@@ -375,27 +552,35 @@ class SDSSClass(BaseQuery):
 
         if not matches:
             request_payload = self._args_to_payload(
-                fields=['instrument', 'run2d', 'plate', 'mjd', 'fiberID'],
+                specobj_fields=['instrument', 'run2d', 'plate',
+                                'mjd', 'fiberID'],
                 coordinates=coordinates, radius=radius, spectro=True,
-                plate=plate, mjd=mjd, fiberID=fiberID)
+                plate=plate, mjd=mjd, fiberID=fiberID,
+                data_release=data_release)
             if get_query_payload:
                 return request_payload
-            r = commons.send_request(SDSS.QUERY_URL, request_payload, timeout,
-                                     request_type='GET')
+
+            url = self._get_query_url(data_release)
+            r = self._request("GET", url, params=request_payload,
+                              timeout=timeout, cache=cache)
+
             matches = self._parse_result(r)
+            if matches is None:
+                warnings.warn("Query returned no results.", NoResultsWarning)
+                return
 
         if not isinstance(matches, Table):
-            raise TypeError("Matches must be an astropy Table.")
+            raise TypeError("'matches' must be an astropy Table.")
 
         results = []
         for row in matches:
-            link = ('{base}/{instrument}/spectro/redux/{run2d}/spectra'
-                    '/{plate:04d}/spec-{plate:04d}-{mjd}-{fiber:04d}.fits')
-            # _parse_result returns bytes for instrunments, requiring a decode
-            link = link.format(base=SDSS.SPECTRO_OPTICAL,
-                               instrument=row['instrument'].decode().lower(),
-                               run2d=row['run2d'], plate=row['plate'],
-                               fiber=row['fiberID'], mjd=row['mjd'])
+            linkstr = self.SPECTRA_URL_SUFFIX
+            # _parse_result returns bytes for instruments, requiring a decode
+            link = linkstr.format(
+                base=conf.sas_baseurl, dr=data_release,
+                instrument=row['instrument'].decode().lower(),
+                run2d=row['run2d'], plate=row['plate'],
+                fiber=row['fiberID'], mjd=row['mjd'])
 
             results.append(commons.FileContainer(link,
                                                  encoding='binary',
@@ -404,9 +589,9 @@ class SDSSClass(BaseQuery):
         return results
 
     @prepend_docstr_noreturns(get_spectra_async.__doc__)
-    def get_spectra(self, coordinates=None, radius=u.degree / 1800.,
+    def get_spectra(self, coordinates=None, radius=2. * u.arcsec,
                     matches=None, plate=None, fiberID=None, mjd=None,
-                    timeout=TIMEOUT):
+                    timeout=TIMEOUT, cache=True, data_release=12):
         """
         Returns
         -------
@@ -417,14 +602,19 @@ class SDSSClass(BaseQuery):
         readable_objs = self.get_spectra_async(coordinates=coordinates,
                                                radius=radius, matches=matches,
                                                plate=plate, fiberID=fiberID,
-                                               mjd=mjd, timeout=timeout)
+                                               mjd=mjd, timeout=timeout,
+                                               data_release=data_release)
 
-        return [obj.get_fits() for obj in readable_objs]
+        if readable_objs is not None:
+            if isinstance(readable_objs, dict):
+                return readable_objs
+            else:
+                return [obj.get_fits() for obj in readable_objs]
 
-    def get_images_async(self, coordinates=None, radius=u.degree / 1800.,
+    def get_images_async(self, coordinates=None, radius=2. * u.arcsec,
                          matches=None, run=None, rerun=301, camcol=None,
                          field=None, band='g', timeout=TIMEOUT,
-                         get_query_payload=False, cache=True):
+                         get_query_payload=False, cache=True, data_release=12):
         """
         Download an image from SDSS.
 
@@ -472,6 +662,11 @@ class SDSSClass(BaseQuery):
             remote server.  Defaults to `SDSSClass.TIMEOUT`.
         cache : bool
             Cache the images using astropy's caching system
+        get_query_payload : bool
+            If True, this will return the data the query would have sent out,
+            but does not actually do the query.
+        data_release : int
+            The data release of the SDSS to use.
 
         Returns
         -------
@@ -504,24 +699,28 @@ class SDSSClass(BaseQuery):
             request_payload = self._args_to_payload(
                 fields=['run', 'rerun', 'camcol', 'field'],
                 coordinates=coordinates, radius=radius, spectro=False, run=run,
-                rerun=rerun, camcol=camcol, field=field)
+                rerun=rerun, camcol=camcol, field=field,
+                data_release=data_release)
             if get_query_payload:
                 return request_payload
-            r = commons.send_request(SDSS.QUERY_URL, request_payload, timeout,
-                                     request_type='GET')
-            matches = self._parse_result(r)
 
+            url = self._get_query_url(data_release)
+            r = self._request("GET", url, params=request_payload,
+                              timeout=timeout, cache=cache)
+            matches = self._parse_result(r)
+            if matches is None:
+                warnings.warn("Query returned no results.", NoResultsWarning)
+                return
         if not isinstance(matches, Table):
-            raise ValueError
+            raise ValueError("'matches' must be an astropy Table")
 
         results = []
         for row in matches:
             for b in band:
                 # Download and read in image data
-                linkstr = ('{base}/{rerun}/{run}/{camcol}/'
-                           'frame-{band}-{run:06d}-{camcol}-'
-                           '{field:04d}.fits.bz2')
-                link = linkstr.format(base=SDSS.IMAGING, run=row['run'],
+                linkstr = self.IMAGING_URL_SUFFIX
+                link = linkstr.format(base=conf.sas_baseurl, run=row['run'],
+                                      dr=data_release,
                                       rerun=row['rerun'], camcol=row['camcol'],
                                       field=row['field'], band=b)
 
@@ -533,9 +732,10 @@ class SDSSClass(BaseQuery):
         return results
 
     @prepend_docstr_noreturns(get_images_async.__doc__)
-    def get_images(self, coordinates=None, radius=u.degree / 1800.,
+    def get_images(self, coordinates=None, radius=2. * u.arcsec,
                    matches=None, run=None, rerun=301, camcol=None, field=None,
-                   band='g', timeout=TIMEOUT, cache=True):
+                   band='g', timeout=TIMEOUT, cache=True,
+                   get_query_payload=False, data_release=12):
         """
         Returns
         -------
@@ -543,14 +743,16 @@ class SDSSClass(BaseQuery):
 
         """
 
-        readable_objs = self.get_images_async(coordinates=coordinates,
-                                              radius=radius, matches=matches,
-                                              run=run, rerun=rerun,
-                                              camcol=camcol, field=field,
-                                              band=band, timeout=timeout,
-                                              get_query_payload=False)
+        readable_objs = self.get_images_async(
+            coordinates=coordinates, radius=radius, matches=matches, run=run,
+            rerun=rerun, data_release=data_release, camcol=camcol, field=field,
+            band=band, timeout=timeout, get_query_payload=get_query_payload)
 
-        return [obj.get_fits() for obj in readable_objs]
+        if readable_objs is not None:
+            if isinstance(readable_objs, dict):
+                return readable_objs
+            else:
+                return [obj.get_fits() for obj in readable_objs]
 
     def get_spectral_template_async(self, kind='qso', timeout=TIMEOUT):
         """
@@ -588,14 +790,14 @@ class SDSSClass(BaseQuery):
         if kind == 'all':
             indices = list(np.arange(33))
         else:
-            indices = spec_templates[kind]
+            indices = self.AVAILABLE_TEMPLATES[kind]
             if type(indices) is not list:
                 indices = [indices]
 
         results = []
         for index in indices:
             name = str(index).zfill(3)
-            link = '%s-%s.fit' % (SDSS.TEMPLATES, name)
+            link = '%s-%s.fit' % (self.TEMPLATES_URL, name)
             results.append(commons.FileContainer(link,
                                                  remote_timeout=timeout,
                                                  encoding='binary'))
@@ -614,7 +816,8 @@ class SDSSClass(BaseQuery):
         readable_objs = self.get_spectral_template_async(kind=kind,
                                                          timeout=timeout)
 
-        return [obj.get_fits() for obj in readable_objs]
+        if readable_objs is not None:
+            return [obj.get_fits() for obj in readable_objs]
 
     def _parse_result(self, response, verbose=False):
         """
@@ -635,25 +838,28 @@ class SDSSClass(BaseQuery):
         if 'error_message' in io.BytesIO(response.content):
             raise RemoteServiceError(response.content)
         arr = np.atleast_1d(np.genfromtxt(io.BytesIO(response.content),
-                            names=True, dtype=None, delimiter=',',
-                            skip_header=1,  # this may be a hack; it is necessary for tests to pass
-                            comments='#'))
+                                          names=True, dtype=None,
+                                          delimiter=',', skip_header=1,
+                                          comments='#'))
 
         if len(arr) == 0:
             return None
         else:
             return Table(arr)
 
-    def _args_to_payload(self, coordinates=None, radius=u.degree / 1800.,
+    def _args_to_payload(self, coordinates=None, radius=2. * u.arcsec,
                          fields=None, spectro=False,
                          plate=None, mjd=None, fiberID=None, run=None,
-                         rerun=301, camcol=None, field=None, photoobj_fields=None, specobj_fields=None):
+                         rerun=301, camcol=None, field=None,
+                         photoobj_fields=None, specobj_fields=None,
+                         field_help=None, obj_names=None, data_release=12):
         """
         Construct the SQL query from the arguments.
 
         Parameters
         ----------
-        coordinates : str or `astropy.coordinates` object or list of coordinates
+        coordinates : str or `astropy.coordinates` object or list of
+            coordinates or `~astropy.table.Column` or coordinates
             The target around which to search. It may be specified as a string
             in which case it is resolved using online services or as the
             appropriate `astropy.coordinates` object. ICRS coordinates may also
@@ -697,35 +903,71 @@ class SDSSClass(BaseQuery):
         specobj_fields: float, optional
             SpecObj quantities to return. If photoobj_fields is None and
             specobj_fields is None then the value of fields is used
+        field_help: str or bool, optional
+            Field name to check whether it is a valid PhotoObjAll or SpecObjAll
+            field name. If `True` or it is an invalid field name all the valid
+            field names are returned as a dict.
+        obj_names : str, or list or `~astropy.table.Column`, optional
+            Target names. If given, every coordinate should have a
+            corresponding name, and it gets repeated in the query result
+        data_release : int
+            The data release of the SDSS to use.
 
         Returns
         -------
         request_payload : dict
 
         """
-        # Fields to return
-        if fields is None:
-            fields = list(photoobj_defs)
-            if spectro:
-                fields += specobj_defs
+        url = self._get_query_url(data_release)
+        # TODO: replace this with something cleaner below
+        photoobj_all = get_field_info(self, 'PhotoObjAll', url,
+                                      self.TIMEOUT)['name']
+
+        specobj_all = get_field_info(self, 'SpecObjAll', url,
+                                     self.TIMEOUT)['name']
+
+        if field_help:
+            ret = 0
+            if field_help in photoobj_all:
+                print("{0} is a valid 'photoobj_field'".format(field_help))
+                ret += 1
+            elif field_help in specobj_all:
+                print("{0} is a valid 'specobj_field'".format(field_help))
+                ret += 1
+
+            if ret > 0:
+                return
+            else:
+                if field_help is not True:
+                    warnings.warn("{0} isn't a valid 'photobj_field' or "
+                                  "'specobj_field' field, valid fields are"
+                                  "returned.".format(field_help))
+                return {'photoobj_all': photoobj_all,
+                        'specobj_all': specobj_all}
 
         # Construct SQL query
         q_select = 'SELECT DISTINCT '
+        q_select_field = []
         if photoobj_fields is None and specobj_fields is None:
-            for sql_field in fields:
-                if sql_field in photoobj_defs:
-                    q_select += 'p.%s,' % sql_field
-                if sql_field in specobj_defs:
-                    q_select += 's.%s,' % sql_field
-        else:
-            if photoobj_fields is not None:
-                for sql_field in photoobj_fields:
-                    q_select += 'p.%s,' % sql_field
-            if specobj_fields is not None:
-                for sql_field in photoobj_fields:
-                    q_select += 's.%s,' % sql_field
-        q_select = q_select.rstrip(',')
-        q_select += ' '
+            # Fields to return
+            if fields is None:
+                photoobj_fields = photoobj_defs
+                if spectro:
+                    specobj_fields = specobj_defs
+            else:
+                for sql_field in fields:
+                    if sql_field.lower() in photoobj_all:
+                        q_select_field.append('p.{0}'.format(sql_field))
+                    elif sql_field.lower() in specobj_all:
+                        q_select_field.append('s.{0}'.format(sql_field))
+
+        if photoobj_fields is not None:
+            for sql_field in photoobj_fields:
+                q_select_field.append('p.{0}'.format(sql_field))
+        if specobj_fields is not None:
+            for sql_field in specobj_fields:
+                q_select_field.append('s.{0}'.format(sql_field))
+        q_select += ', '.join(q_select_field)
 
         q_from = 'FROM PhotoObjAll AS p '
         if spectro:
@@ -736,9 +978,9 @@ class SDSSClass(BaseQuery):
         q_where = 'WHERE '
         if coordinates is not None:
             if (not isinstance(coordinates, list) and
+                not isinstance(coordinates, Column) and
                 not (isinstance(coordinates, commons.CoordClasses) and
-                not coordinates.isscalar)
-            ):
+                     not coordinates.isscalar)):
                 coordinates = [coordinates]
             for n, target in enumerate(coordinates):
                 # Query for a region
@@ -750,8 +992,8 @@ class SDSSClass(BaseQuery):
                 if n > 0:
                     q_where += ' or '
                 q_where += ('((p.ra between %g and %g) and '
-                           '(p.dec between %g and %g))'
-                           % (ra - dr, ra + dr, dec - dr, dec + dr))
+                            '(p.dec between %g and %g))'
+                            % (ra - dr, ra + dr, dec - dr, dec + dr))
         elif spectro:
             # Spectra: query for specified plate, mjd, fiberid
             s_fields = ['s.%s=%d' % (key, val) for (key, val) in
@@ -776,9 +1018,35 @@ class SDSSClass(BaseQuery):
                 raise ValueError('must specify at least one of `coordinates`, '
                                  '`run`, `camcol` or `field`')
 
-        sql = "%s%s%s%s" % (q_select, q_from, q_join, q_where)
+        sql = "{0} {1} {2} {3}".format(q_select, q_from, q_join, q_where)
+
         request_payload = dict(cmd=sql, format='csv')
 
+        if data_release > 11:
+            request_payload['searchtool'] = 'SQL'
+
         return request_payload
 
+    def _get_query_url(self, data_release):
+        if data_release < 10:
+            suffix = self.QUERY_URL_SUFFIX_DR_OLD
+        elif data_release == 10:
+            suffix = self.QUERY_URL_SUFFIX_DR_10
+        else:
+            suffix = self.QUERY_URL_SUFFIX_DR_NEW
+
+        url = conf.skyserver_baseurl + suffix.format(dr=data_release)
+        self._last_url = url
+        return url
+
+    def _get_crossid_url(self, data_release):
+        if data_release < 11:
+            suffix = self.XID_URL_SUFFIX_OLD
+        else:
+            suffix = self.XID_URL_SUFFIX_NEW
+
+        url = conf.skyserver_baseurl + suffix.format(dr=data_release)
+        self._last_url = url
+        return url
+
 SDSS = SDSSClass()
