@@ -5,14 +5,17 @@ import os
 import warnings
 import json
 import copy
+import re
 
 from astropy.extern import six
+from astropy.extern.six import BytesIO
 import astropy.units as u
 import astropy.coordinates as coord
 import astropy.table as tbl
 import astropy.utils.data as aud
-from astropy.utils import OrderedDict
+from collections import OrderedDict
 import astropy.io.votable as votable
+from astropy.io import ascii, fits
 
 from ..query import BaseQuery
 from ..utils import commons
@@ -31,16 +34,21 @@ __doctest_skip__ = ['VizierClass.*']
 class VizierClass(BaseQuery):
 
     _str_schema = schema.Or(*six.string_types)
-    _schema_columns = schema.Schema([_str_schema], error="columns must be a list of strings")
+    _schema_columns = schema.Schema([_str_schema],
+                                    error="columns must be a list of strings")
     _schema_ucd = schema.Schema(_str_schema, error="ucd must be string")
-    _schema_column_filters = schema.Schema({schema.Optional(_str_schema):_str_schema},
-                                           error="column_filters must be a dictionary where both keys and values are strings")
-    _schema_catalog = schema.Schema(schema.Or([_str_schema], _str_schema, None),
-                                    error="catalog must be a list of strings or a single string")
+    _schema_column_filters = schema.Schema(
+        {schema.Optional(_str_schema): _str_schema},
+        error=("column_filters must be a dictionary where both keys "
+               "and values are strings"))
+    _schema_catalog = schema.Schema(
+        schema.Or([_str_schema], _str_schema, None),
+        error="catalog must be a list of strings or a single string")
+
+    def __init__(self, columns=["*"], column_filters={}, catalog=None,
+                 keywords=None, ucd="", timeout=conf.timeout,
+                 vizier_server=conf.server, row_limit=conf.row_limit):
 
-    def __init__(self, columns=["*"], column_filters={}, catalog=None, keywords=None,
-                 ucd="", timeout=conf.timeout, vizier_server=conf.server,
-                 row_limit=conf.row_limit):
         super(VizierClass, self).__init__()
         self.columns = columns
         self.column_filters = column_filters
@@ -66,16 +74,23 @@ class VizierClass(BaseQuery):
 
     @property
     def column_filters(self):
-        """Filters to run on the individual columns.  See the Vizier website for details."""
+        """
+        Filters to run on the individual columns. See the Vizier website
+        for details.
+        """
         return self._column_filters
 
     @column_filters.setter
     def column_filters(self, values):
-        self._column_filters = VizierClass._schema_column_filters.validate(values)
+        self._column_filters = (
+            VizierClass._schema_column_filters.validate(values))
 
     @property
     def catalog(self):
-        """The default catalog to search.  If left empty, will search all catalogs."""
+        """
+        The default catalog to search.  If left empty, will search all
+        catalogs.
+        """
         return self._catalog
 
     @catalog.setter
@@ -110,6 +125,19 @@ class VizierClass(BaseQuery):
         FITS binary table: asu-binfits
         plain text: asu-txt
         """
+
+        # Only votable is supported now, but in case we try to support
+        # something in the future we should disallow invalid ones.
+        assert return_type in ('votable', 'asu-tsv', 'asu-fits',
+                               'asu-binfits', 'asu-txt')
+        if return_type in ('asu-txt',):
+            # I had a look at the format of these "tables" and... they just
+            # aren't.  They're quasi-fixed-width without schema.  I think they
+            # follow the general philosophy of "consistency is overrated"
+            # The CDS reader chokes on it.
+            raise TypeError("asu-txt is not and cannot be supported: the "
+                            "returned tables are not and cannot be made "
+                            "parseable.")
         return "http://" + self.VIZIER_SERVER + "/viz-bin/" + return_type
 
     @property
@@ -126,7 +154,7 @@ class VizierClass(BaseQuery):
         self._keywords = None
 
     def find_catalogs(self, keywords, include_obsolete=False, verbose=False,
-                      max_catalogs=None):
+                      max_catalogs=None, return_type='votable'):
         """
         Search Vizier for catalogs based on a set of keywords, e.g. author name
 
@@ -145,9 +173,10 @@ class VizierClass(BaseQuery):
 
         Returns
         -------
-        resource_dict : Dictionary of the "Resource" name and the VOTable resource object.
-        "Resources" are generally publications; one publication may contain
-        many tables.
+        resource_dict : dict
+            Dictionary of the "Resource" name and the VOTable resource object.
+            "Resources" are generally publications; one publication may contain
+            many tables.
 
         Examples
         --------
@@ -167,25 +196,28 @@ class VizierClass(BaseQuery):
         data_payload = {'-words': keywords, '-meta.all': 1}
         if max_catalogs is not None:
             data_payload['-meta.max'] = max_catalogs
-        response = self._request(method='POST',
-                                 url=self._server_to_url(),
-                                 data=data_payload,
-                                 timeout=self.TIMEOUT)
-        if 'STOP, Max. number of RESOURCE reached' in response.content:
-            raise ValueError("Maximum number of catalogs exceeded.  Try setting max_catalogs "
-                             "to a large number and try again")
-        result = self._parse_result(response, verbose=verbose, get_catalog_names=True)
+        response = self._request(
+            method='POST', url=self._server_to_url(return_type=return_type),
+            data=data_payload, timeout=self.TIMEOUT)
+
+        if 'STOP, Max. number of RESOURCE reached' in response.text:
+            raise ValueError("Maximum number of catalogs exceeded.  Try "
+                             "setting max_catalogs to a large number and"
+                             " try again")
+        result = self._parse_result(response, verbose=verbose,
+                                    get_catalog_names=True)
 
         # Filter out the obsolete catalogs, unless requested
         if include_obsolete is False:
-            for (key, resource) in result.items():
-                for info in resource.infos:
+            for key in list(result):
+                for info in result[key].infos:
                     if (info.name == 'status') and (info.value == 'obsolete'):
                         del result[key]
 
         return result
 
-    def get_catalogs_async(self, catalog, verbose=False):
+    def get_catalogs_async(self, catalog, verbose=False, return_type='votable',
+                           get_query_payload=False):
         """
         Query the Vizier service for a specific catalog
 
@@ -201,14 +233,18 @@ class VizierClass(BaseQuery):
         """
 
         data_payload = self._args_to_payload(catalog=catalog)
-        response = self._request(method='POST',
-                                 url=self._server_to_url(),
-                                 data=data_payload,
-                                 timeout=self.TIMEOUT)
+        if get_query_payload:
+            return data_payload
+
+        response = self._request(
+            method='POST', url=self._server_to_url(return_type=return_type),
+            data=data_payload, timeout=self.TIMEOUT)
+
         return response
 
     def query_object_async(self, object_name, catalog=None, radius=None,
-                           coordinate_frame=None):
+                           coordinate_frame=None, get_query_payload=False,
+                           return_type='votable', cache=True):
         """
         Serves the same purpose as `query_object` but only
         returns the HTTP response rather than the parsed result.
@@ -224,8 +260,9 @@ class VizierClass(BaseQuery):
             A degree-equivalent unit (optional)
         coordinate_system : str or None
             If the object name is given as a coordinate, you *should* use
-            `query_region`, but you can specify a coordinate frame here instead
-            (today, J2000, B1975, B1950, B1900, B1875, B1855, Galactic, Supergal., Ecl.J2000, )
+            `query_region`, but you can specify a coordinate frame here
+            instead (today, J2000, B1975, B1950, B1900, B1875, B1855,
+            Galactic, Supergal., Ecl.J2000, )
 
         Returns
         -------
@@ -239,24 +276,27 @@ class VizierClass(BaseQuery):
         else:
             radius_arcmin = radius.to(u.arcmin).value
             cframe = (coordinate_frame if coordinate_frame in
-                      'today,J2000,B1975,B1950,B1900,B1875,B1855,Galactic,Supergal.,Ecl.J2000'.split(",")
+                      ["today", "J2000", "B1975", "B1950", "B1900", "B1875",
+                       "B1855", "Galactic", "Supergal.", "Ecl.J2000"]
                       else 'J2000')
-            # oname = "{name}({arcmin} {cframe})".format(name=object_name, arcmin=radius_arcmin, cframe)
-            center = {'-c': object_name, '-c.u':'arcmin', '-c.geom':'r',
-                      '-c.r': radius_arcmin, '-c.eq':cframe}
+
+            center = {'-c': object_name, '-c.u': 'arcmin', '-c.geom': 'r',
+                      '-c.r': radius_arcmin, '-c.eq': cframe}
 
         data_payload = self._args_to_payload(
             center=center,
             catalog=catalog)
-        response = self._request(method='POST',
-                                 url=self._server_to_url(),
-                                 data=data_payload,
-                                 timeout=self.TIMEOUT)
+        if get_query_payload:
+            return data_payload
+        response = self._request(
+            method='POST', url=self._server_to_url(return_type=return_type),
+            data=data_payload, timeout=self.TIMEOUT, cache=cache)
         return response
 
     def query_region_async(self, coordinates, radius=None, inner_radius=None,
                            width=None, height=None, catalog=None,
-                           get_query_payload=False):
+                           get_query_payload=False, cache=True,
+                           return_type='votable'):
         """
         Serves the same purpose as `query_region` but only
         returns the HTTP response rather than the parsed result.
@@ -264,22 +304,23 @@ class VizierClass(BaseQuery):
         Parameters
         ----------
         coordinates : str, `astropy.coordinates` object, or `~astropy.table.Table`
-            The target around which to search. It may be specified as a string
-            in which case it is resolved using online services or as the appropriate
-            `astropy.coordinates` object. ICRS coordinates may also be entered as
-            a string.
-            If a table is used, each of its rows will be queried, as long as it contains
-            two columns named ``_RAJ2000`` and ``_DEJ2000`` with proper angular units.
+            The target around which to search. It may be specified as a
+            string in which case it is resolved using online services or as
+            the appropriate `astropy.coordinates` object. ICRS coordinates
+            may also be entered as a string.  If a table is used, each of
+            its rows will be queried, as long as it contains two columns
+            named ``_RAJ2000`` and ``_DEJ2000`` with proper angular units.
         radius : convertible to `~astropy.coordinates.Angle`
             The radius of the circular region to query.
         inner_radius : convertible to `~astropy.coordinates.Angle`
-            When set in addition to ``radius``, the queried region becomes annular,
-            with outer radius ``radius`` and inner radius ``inner_radius``.
+            When set in addition to ``radius``, the queried region becomes
+            annular, with outer radius ``radius`` and inner radius
+            ``inner_radius``.
         width : convertible to `~astropy.coordinates.Angle`
             The width of the square region to query.
         height : convertible to `~astropy.coordinates.Angle`
-            When set in addition to ``width``, the queried region becomes rectangular,
-            with the specified ``width`` and ``height``.
+            When set in addition to ``width``, the queried region becomes
+            rectangular, with the specified ``width`` and ``height``.
         catalog : str or list, optional
             The catalog(s) which must be searched for this identifier.
             If not specified, all matching catalogs will be searched.
@@ -299,7 +340,8 @@ class VizierClass(BaseQuery):
             if not c.isscalar:
                 pos_list = []
                 for pos in c:
-                    ra_deg = pos.ra.to_string(unit="deg", decimal=True, precision=8)
+                    ra_deg = pos.ra.to_string(unit="deg", decimal=True,
+                                              precision=8)
                     dec_deg = pos.dec.to_string(unit="deg", decimal=True,
                                                 precision=8, alwayssign=True)
                     pos_list += ["{}{}".format(ra_deg, dec_deg)]
@@ -315,21 +357,23 @@ class VizierClass(BaseQuery):
                                                         coordinates.keys())):
                 pos_list = []
                 sky_coord = coord.SkyCoord(coordinates["_RAJ2000"],
-                                          coordinates["_DEJ2000"],
-                                          unit=(coordinates["_RAJ2000"].unit,
-                                                coordinates["_DEJ2000"].unit))
+                                           coordinates["_DEJ2000"],
+                                           unit=(coordinates["_RAJ2000"].unit,
+                                                 coordinates["_DEJ2000"].unit))
                 for (ra, dec) in zip(sky_coord.ra, sky_coord.dec):
-                    ra_deg = ra.to_string(unit="deg", decimal=True, precision=8)
+                    ra_deg = ra.to_string(unit="deg", decimal=True,
+                                          precision=8)
                     dec_deg = dec.to_string(unit="deg", decimal=True,
                                             precision=8, alwayssign=True)
                     pos_list += ["{}{}".format(ra_deg, dec_deg)]
                 center["-c"] = "<<;" + ";".join(pos_list)
                 columns += ["_q"]  # request a reference to the input table
             else:
-                raise ValueError("Table must contain '_RAJ2000' and '_DEJ2000' columns!")
+                raise ValueError("Table must contain '_RAJ2000' and "
+                                 "'_DEJ2000' columns!")
         else:
-            raise TypeError("Coordinates must be one of: string, astropy coordinates,"
-                            " or table containing coordinates!")
+            raise TypeError("Coordinates must be one of: string, astropy "
+                            "coordinates, or table containing coordinates!")
         # decide whether box or radius
         if radius is not None:
             # is radius a disk or an annulus?
@@ -373,16 +417,17 @@ class VizierClass(BaseQuery):
         if get_query_payload:
             return data_payload
 
-        response = self._request(method='POST',
-                                 url=self._server_to_url(),
-                                 data=data_payload,
-                                 timeout=self.TIMEOUT)
+        response = self._request(
+            method='POST', url=self._server_to_url(return_type=return_type),
+            data=data_payload, timeout=self.TIMEOUT, cache=cache)
         return response
 
-    def query_constraints_async(self, catalog=None, **kwargs):
+    def query_constraints_async(self, catalog=None, return_type='votable',
+                                cache=True,
+                                **kwargs):
         """
-        Send a query to Vizier in which you specify constraints with keyword/value
-        pairs.
+        Send a query to Vizier in which you specify constraints with
+        keyword/value pairs.
 
         See `the vizier constraints page
         <http://vizier.cfa.harvard.edu/vizier/vizHelp/cst.htx>`_ for details.
@@ -405,7 +450,8 @@ class VizierClass(BaseQuery):
         --------
         >>> from astroquery.vizier import Vizier
         >>> # note that glon/glat constraints here *must* be floats
-        >>> result = Vizier.query_constraints(catalog='J/ApJ/723/492/table1',GLON='>49.0 & < 51.0', GLAT='<0.0')
+        >>> result = Vizier.query_constraints(catalog='J/ApJ/723/492/table1',
+        ...                                   GLON='>49.0 & <51.0', GLAT='<0')
         >>> result[result.keys()[0]].pprint()
             GRSMC      GLON   GLAT   VLSR  ... RD09 _RA.icrs _DE.icrs
         ------------- ------ ------ ------ ... ---- -------- --------
@@ -436,10 +482,9 @@ class VizierClass(BaseQuery):
             catalog=catalog,
             column_filters=kwargs,
             center={'-c.rd': 180})
-        response = self._request(method='POST',
-                                 url=self._server_to_url(),
-                                 data=data_payload,
-                                 timeout=self.TIMEOUT)
+        response = self._request(
+            method='POST', url=self._server_to_url(return_type=return_type),
+            data=data_payload, timeout=self.TIMEOUT, cache=cache)
         return response
 
     def _args_to_payload(self, *args, **kwargs):
@@ -468,7 +513,7 @@ class VizierClass(BaseQuery):
             columns = self.columns + columns
 
         # keyword names that can mean 'all' need to be treated separately
-        alls = ['all','*']
+        alls = ['all', '*']
         if any(x in columns for x in alls):
             for x in alls:
                 if x in columns:
@@ -526,11 +571,13 @@ class VizierClass(BaseQuery):
         script = "\n".join(["{key}={val}".format(key=key, val=val)
                             for key, val in body.items()])
         # add keywords
-        if not isinstance(self.keywords, property) and self.keywords is not None:
+        if (not isinstance(self.keywords, property) and
+                self.keywords is not None):
             script += "\n" + str(self.keywords)
         return script
 
-    def _parse_result(self, response, get_catalog_names=False, verbose=False, invalid='warn'):
+    def _parse_result(self, response, get_catalog_names=False, verbose=False,
+                      invalid='warn'):
         """
         Parses the HTTP response to create a `~astropy.table.Table`.
 
@@ -541,63 +588,46 @@ class VizierClass(BaseQuery):
         response : `requests.Response`
             The response of the HTTP POST request
         get_catalog_names : bool
+            (only for VOTABLE queries)
             If specified, return only the table names (useful for table
-            discovery)
-        invalid : 'warn', 'mask' or 'raise'
-            The behavior if a VOTABLE cannot be parsed.  Default is 'warn',
-            which will try to parse the table, then if an exception is raised,
-            it will be printent but the masked table will be returned
+            discovery).
+        invalid : 'warn', 'mask' or 'exception'
+            (only for VOTABLE queries)
+            The behavior if a VOTABLE cannot be parsed. The default is
+            'warn', which will try to parse the table, but if an
+            exception is raised during parsing, the exception will be
+            issued as a warning instead and a masked table will be
+            returned. A value of 'exception' will not catch the
+            exception, while a value of 'mask' will simply always mask
+            invalid values.
 
         Returns
         -------
         table_list : `astroquery.utils.TableList` or str
-            If there are errors in the parsing, then returns the raw results as a string.
+            If there are errors in the parsing, then returns the raw results
+            as a string.
+
         """
-        if not verbose:
-            commons.suppress_vo_warnings()
-        try:
-            tf = six.BytesIO(response.content)
-
-            if invalid == 'mask':
-                vo_tree = votable.parse(tf, pedantic=False, invalid='mask')
-            elif invalid == 'warn':
-                try:
-                    vo_tree = votable.parse(tf, pedantic=False, invalid='raise')
-                except Exception as ex:
-                    warnings.warn("VOTABLE parsing raised exception: {0}".format(ex))
-                    vo_tree = votable.parse(tf, pedantic=False, invalid='mask')
-            elif invalid == 'raise':
-                vo_tree = votable.parse(tf, pedantic=False, invalid='raise')
-            else:
-                raise ValueError("Invalid keyword 'invalid'.  Must be raise, mask, or warn")
-
-            if get_catalog_names:
-                return dict([(R.name, R) for R in vo_tree.resources])
-            else:
-                table_dict = OrderedDict()
-                for t in vo_tree.iter_tables():
-                    if len(t.array) > 0:
-                        if t.ref is not None:
-                            name = vo_tree.get_table_by_id(t.ref).name
-                        else:
-                            name = t.name
-                        if name not in table_dict.keys():
-                            table_dict[name] = []
-                        table_dict[name] += [t.to_table()]
-                for name in table_dict.keys():
-                    if len(table_dict[name]) > 1:
-                        table_dict[name] = tbl.vstack(table_dict[name])
-                    else:
-                        table_dict[name] = table_dict[name][0]
-                return commons.TableList(table_dict)
-
-        except Exception as ex:
-            self.response = response
-            self.table_parse_error = ex
-            raise TableParseError("Failed to parse VIZIER result! The raw response can be found "
-                                  "in self.response, and the error in self.table_parse_error."
-                                  "  The attempted parsed result is in self.parsed_result.\n"
-                                  "Exception: " + str(self.table_parse_error))
+        if response.content[:5] == b'<?xml':
+            try:
+                return parse_vizier_votable(
+                    response.content, verbose=verbose, invalid=invalid,
+                    get_catalog_names=get_catalog_names)
+            except Exception as ex:
+                self.response = response
+                self.table_parse_error = ex
+                raise TableParseError("Failed to parse VIZIER result! The "
+                                      "raw response can be found in "
+                                      "self.response, and the error in "
+                                      "self.table_parse_error. The attempted "
+                                      "parsed result is in "
+                                      "self.parsed_result.\n Exception: " +
+                                      str(self.table_parse_error))
+        elif response.content[:5] == b'#\n#  ':
+            return parse_vizier_tsvfile(response.content, verbose=verbose)
+        elif response.content[:6] == b'SIMPLE':
+            return fits.open(BytesIO(response.content),
+                             ignore_missing_end=True)
 
     @property
     def valid_keywords(self):
@@ -607,14 +637,81 @@ class VizierClass(BaseQuery):
             with open(file_name, 'r') as f:
                 kwd = json.load(f)
                 self._valid_keyword_types = sorted(kwd.values())
-                self._valid_keyword_dict = OrderedDict([(k, kwd[k]) for k in sorted(kwd)])
+                self._valid_keyword_dict = OrderedDict([(k, kwd[k])
+                                                        for k in sorted(kwd)])
 
         return self._valid_keyword_dict
 
 
+def parse_vizier_tsvfile(data, verbose=False):
+    """
+    Parse a Vizier-generated list of tsv data tables into a list of astropy
+    Tables.
+
+    Parameters
+    ----------
+    data : ascii str
+        An ascii string containing the vizier-formatted list of tables
+    """
+
+    # http://stackoverflow.com/questions/4664850/find-all-occurrences-of-a-substring-in-python
+    split_indices = [m.start() for m in re.finditer('\n\n#', data)]
+    # we want to slice out chunks of the file each time
+    split_limits = zip(split_indices[:-1], split_indices[1:])
+    tables = [ascii.read(BytesIO(data[a:b]), format='fast_tab', delimiter='\t',
+                         header_start=0, comment="#") for
+              a, b in split_limits]
+    return tables
+
+
+def parse_vizier_votable(data, verbose=False, invalid='warn',
+                         get_catalog_names=False):
+    """
+    Given a votable as string, parse it into tables
+    """
+    if not verbose:
+        commons.suppress_vo_warnings()
+
+    tf = BytesIO(data)
+
+    if invalid == 'mask':
+        vo_tree = votable.parse(tf, pedantic=False, invalid='mask')
+    elif invalid == 'warn':
+        try:
+            vo_tree = votable.parse(tf, pedantic=False, invalid='exception')
+        except Exception as ex:
+            warnings.warn("VOTABLE parsing raised exception: {0}".format(ex))
+            vo_tree = votable.parse(tf, pedantic=False, invalid='mask')
+    elif invalid == 'exception':
+        vo_tree = votable.parse(tf, pedantic=False, invalid='exception')
+    else:
+        raise ValueError("Invalid keyword for 'invalid'. "
+                         "Must be exception, mask, or warn")
+
+    if get_catalog_names:
+        return dict([(R.name, R) for R in vo_tree.resources])
+    else:
+        table_dict = OrderedDict()
+        for t in vo_tree.iter_tables():
+            if len(t.array) > 0:
+                if t.ref is not None:
+                    name = vo_tree.get_table_by_id(t.ref).name
+                else:
+                    name = t.name
+                if name not in table_dict.keys():
+                    table_dict[name] = []
+                table_dict[name] += [t.to_table()]
+        for name in table_dict.keys():
+            if len(table_dict[name]) > 1:
+                table_dict[name] = tbl.vstack(table_dict[name])
+            else:
+                table_dict[name] = table_dict[name][0]
+        return commons.TableList(table_dict)
+
+
 def _parse_angle(angle):
     """
-    Retuns the Vizier-formatted units and values for box/radius
+    Returns the Vizier-formatted units and values for box/radius
     dimensions in case of region queries.
 
     Parameters
@@ -652,7 +749,10 @@ class VizierKeyword(list):
 
     @property
     def keywords(self):
-        """List or string for keyword(s) that must be set for the Vizier object."""
+        """
+        List or string for keyword(s) that must be set for the Vizier
+        object.
+        """
         return self._keywords
 
     @keywords.setter
@@ -676,16 +776,16 @@ class VizierKeyword(list):
                 else:
                     set_keywords[self.keyword_dict[key]] = [key]
         self._keywords = OrderedDict(
-                [(k, sorted(set_keywords[k]))
-                 for k in set_keywords]
-                )
+            [(k, sorted(set_keywords[k]))
+             for k in set_keywords])
 
     @keywords.deleter
     def keywords(self):
         del self._keywords
 
     def __repr__(self):
-        return "\n".join([x for key in self.keywords for x in self.get_keyword_str(key)])
+        return "\n".join([x for key in self.keywords
+                          for x in self.get_keyword_str(key)])
 
     def get_keyword_str(self, key):
         """
